# coding: utf-8

"""
    Metadata API

    The Metadata API has operations that retrieve configuration details pertaining to the different eBay marketplaces. In addition to marketplace information, the API also has operations that get information that helps sellers list items on eBay.  # noqa: E501

    OpenAPI spec version: v1.10.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ClassifiedAdPolicy(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ad_format_enabled': 'str',
        'category_id': 'str',
        'category_tree_id': 'str',
        'classified_ad_auto_accept_enabled': 'bool',
        'classified_ad_auto_decline_enabled': 'bool',
        'classified_ad_best_offer_enabled': 'str',
        'classified_ad_company_name_enabled': 'bool',
        'classified_ad_contact_by_address_enabled': 'bool',
        'classified_ad_contact_by_email_enabled': 'bool',
        'classified_ad_contact_by_phone_enabled': 'bool',
        'classified_ad_counter_offer_enabled': 'bool',
        'classified_ad_payment_method_enabled': 'str',
        'classified_ad_phone_count': 'int',
        'classified_ad_shipping_method_enabled': 'bool',
        'classified_ad_street_count': 'int',
        'seller_contact_details_enabled': 'bool'
    }

    attribute_map = {
        'ad_format_enabled': 'adFormatEnabled',
        'category_id': 'categoryId',
        'category_tree_id': 'categoryTreeId',
        'classified_ad_auto_accept_enabled': 'classifiedAdAutoAcceptEnabled',
        'classified_ad_auto_decline_enabled': 'classifiedAdAutoDeclineEnabled',
        'classified_ad_best_offer_enabled': 'classifiedAdBestOfferEnabled',
        'classified_ad_company_name_enabled': 'classifiedAdCompanyNameEnabled',
        'classified_ad_contact_by_address_enabled': 'classifiedAdContactByAddressEnabled',
        'classified_ad_contact_by_email_enabled': 'classifiedAdContactByEmailEnabled',
        'classified_ad_contact_by_phone_enabled': 'classifiedAdContactByPhoneEnabled',
        'classified_ad_counter_offer_enabled': 'classifiedAdCounterOfferEnabled',
        'classified_ad_payment_method_enabled': 'classifiedAdPaymentMethodEnabled',
        'classified_ad_phone_count': 'classifiedAdPhoneCount',
        'classified_ad_shipping_method_enabled': 'classifiedAdShippingMethodEnabled',
        'classified_ad_street_count': 'classifiedAdStreetCount',
        'seller_contact_details_enabled': 'sellerContactDetailsEnabled'
    }

    def __init__(self, ad_format_enabled=None, category_id=None, category_tree_id=None, classified_ad_auto_accept_enabled=None, classified_ad_auto_decline_enabled=None, classified_ad_best_offer_enabled=None, classified_ad_company_name_enabled=None, classified_ad_contact_by_address_enabled=None, classified_ad_contact_by_email_enabled=None, classified_ad_contact_by_phone_enabled=None, classified_ad_counter_offer_enabled=None, classified_ad_payment_method_enabled=None, classified_ad_phone_count=None, classified_ad_shipping_method_enabled=None, classified_ad_street_count=None, seller_contact_details_enabled=None):  # noqa: E501
        """ClassifiedAdPolicy - a model defined in Swagger"""  # noqa: E501
        self._ad_format_enabled = None
        self._category_id = None
        self._category_tree_id = None
        self._classified_ad_auto_accept_enabled = None
        self._classified_ad_auto_decline_enabled = None
        self._classified_ad_best_offer_enabled = None
        self._classified_ad_company_name_enabled = None
        self._classified_ad_contact_by_address_enabled = None
        self._classified_ad_contact_by_email_enabled = None
        self._classified_ad_contact_by_phone_enabled = None
        self._classified_ad_counter_offer_enabled = None
        self._classified_ad_payment_method_enabled = None
        self._classified_ad_phone_count = None
        self._classified_ad_shipping_method_enabled = None
        self._classified_ad_street_count = None
        self._seller_contact_details_enabled = None
        self.discriminator = None
        if ad_format_enabled is not None:
            self.ad_format_enabled = ad_format_enabled
        if category_id is not None:
            self.category_id = category_id
        if category_tree_id is not None:
            self.category_tree_id = category_tree_id
        if classified_ad_auto_accept_enabled is not None:
            self.classified_ad_auto_accept_enabled = classified_ad_auto_accept_enabled
        if classified_ad_auto_decline_enabled is not None:
            self.classified_ad_auto_decline_enabled = classified_ad_auto_decline_enabled
        if classified_ad_best_offer_enabled is not None:
            self.classified_ad_best_offer_enabled = classified_ad_best_offer_enabled
        if classified_ad_company_name_enabled is not None:
            self.classified_ad_company_name_enabled = classified_ad_company_name_enabled
        if classified_ad_contact_by_address_enabled is not None:
            self.classified_ad_contact_by_address_enabled = classified_ad_contact_by_address_enabled
        if classified_ad_contact_by_email_enabled is not None:
            self.classified_ad_contact_by_email_enabled = classified_ad_contact_by_email_enabled
        if classified_ad_contact_by_phone_enabled is not None:
            self.classified_ad_contact_by_phone_enabled = classified_ad_contact_by_phone_enabled
        if classified_ad_counter_offer_enabled is not None:
            self.classified_ad_counter_offer_enabled = classified_ad_counter_offer_enabled
        if classified_ad_payment_method_enabled is not None:
            self.classified_ad_payment_method_enabled = classified_ad_payment_method_enabled
        if classified_ad_phone_count is not None:
            self.classified_ad_phone_count = classified_ad_phone_count
        if classified_ad_shipping_method_enabled is not None:
            self.classified_ad_shipping_method_enabled = classified_ad_shipping_method_enabled
        if classified_ad_street_count is not None:
            self.classified_ad_street_count = classified_ad_street_count
        if seller_contact_details_enabled is not None:
            self.seller_contact_details_enabled = seller_contact_details_enabled

    @property
    def ad_format_enabled(self):
        """Gets the ad_format_enabled of this ClassifiedAdPolicy.  # noqa: E501

        This enumerated value indicates the type or status of available Classified Ad formats for this category. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:AdFormatEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :return: The ad_format_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: str
        """
        return self._ad_format_enabled

    @ad_format_enabled.setter
    def ad_format_enabled(self, ad_format_enabled):
        """Sets the ad_format_enabled of this ClassifiedAdPolicy.

        This enumerated value indicates the type or status of available Classified Ad formats for this category. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:AdFormatEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :param ad_format_enabled: The ad_format_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: str
        """

        self._ad_format_enabled = ad_format_enabled

    @property
    def category_id(self):
        """Gets the category_id of this ClassifiedAdPolicy.  # noqa: E501

        The unique identifier of the eBay leaf category for which metadata is being returned.  # noqa: E501

        :return: The category_id of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this ClassifiedAdPolicy.

        The unique identifier of the eBay leaf category for which metadata is being returned.  # noqa: E501

        :param category_id: The category_id of this ClassifiedAdPolicy.  # noqa: E501
        :type: str
        """

        self._category_id = category_id

    @property
    def category_tree_id(self):
        """Gets the category_tree_id of this ClassifiedAdPolicy.  # noqa: E501

        The unique identifier of the category tree.  # noqa: E501

        :return: The category_tree_id of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: str
        """
        return self._category_tree_id

    @category_tree_id.setter
    def category_tree_id(self, category_tree_id):
        """Sets the category_tree_id of this ClassifiedAdPolicy.

        The unique identifier of the category tree.  # noqa: E501

        :param category_tree_id: The category_tree_id of this ClassifiedAdPolicy.  # noqa: E501
        :type: str
        """

        self._category_tree_id = category_tree_id

    @property
    def classified_ad_auto_accept_enabled(self):
        """Gets the classified_ad_auto_accept_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether the category supports the Best Offer Automatic Accept feature for Classified Ad listings.  # noqa: E501

        :return: The classified_ad_auto_accept_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_auto_accept_enabled

    @classified_ad_auto_accept_enabled.setter
    def classified_ad_auto_accept_enabled(self, classified_ad_auto_accept_enabled):
        """Sets the classified_ad_auto_accept_enabled of this ClassifiedAdPolicy.

        Indicates whether the category supports the Best Offer Automatic Accept feature for Classified Ad listings.  # noqa: E501

        :param classified_ad_auto_accept_enabled: The classified_ad_auto_accept_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_auto_accept_enabled = classified_ad_auto_accept_enabled

    @property
    def classified_ad_auto_decline_enabled(self):
        """Gets the classified_ad_auto_decline_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether the category supports the Best Offer Automatic Reject feature for Classified Ad listings.  # noqa: E501

        :return: The classified_ad_auto_decline_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_auto_decline_enabled

    @classified_ad_auto_decline_enabled.setter
    def classified_ad_auto_decline_enabled(self, classified_ad_auto_decline_enabled):
        """Sets the classified_ad_auto_decline_enabled of this ClassifiedAdPolicy.

        Indicates whether the category supports the Best Offer Automatic Reject feature for Classified Ad listings.  # noqa: E501

        :param classified_ad_auto_decline_enabled: The classified_ad_auto_decline_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_auto_decline_enabled = classified_ad_auto_decline_enabled

    @property
    def classified_ad_best_offer_enabled(self):
        """Gets the classified_ad_best_offer_enabled of this ClassifiedAdPolicy.  # noqa: E501

        This enumerated value indicates if Best Offer is enabled, disabled, or required for Classified Ad listings in this category. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdBestOfferEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :return: The classified_ad_best_offer_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: str
        """
        return self._classified_ad_best_offer_enabled

    @classified_ad_best_offer_enabled.setter
    def classified_ad_best_offer_enabled(self, classified_ad_best_offer_enabled):
        """Sets the classified_ad_best_offer_enabled of this ClassifiedAdPolicy.

        This enumerated value indicates if Best Offer is enabled, disabled, or required for Classified Ad listings in this category. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdBestOfferEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :param classified_ad_best_offer_enabled: The classified_ad_best_offer_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: str
        """

        self._classified_ad_best_offer_enabled = classified_ad_best_offer_enabled

    @property
    def classified_ad_company_name_enabled(self):
        """Gets the classified_ad_company_name_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether this category supports including a company name in the seller's contact information. This element is for <b>For Sale By Owner</b> listings.   # noqa: E501

        :return: The classified_ad_company_name_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_company_name_enabled

    @classified_ad_company_name_enabled.setter
    def classified_ad_company_name_enabled(self, classified_ad_company_name_enabled):
        """Sets the classified_ad_company_name_enabled of this ClassifiedAdPolicy.

        Indicates whether this category supports including a company name in the seller's contact information. This element is for <b>For Sale By Owner</b> listings.   # noqa: E501

        :param classified_ad_company_name_enabled: The classified_ad_company_name_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_company_name_enabled = classified_ad_company_name_enabled

    @property
    def classified_ad_contact_by_address_enabled(self):
        """Gets the classified_ad_contact_by_address_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether this category supports including an address in the seller's contact information. This element is for <b>For Sale By Owner</b> listings.   # noqa: E501

        :return: The classified_ad_contact_by_address_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_contact_by_address_enabled

    @classified_ad_contact_by_address_enabled.setter
    def classified_ad_contact_by_address_enabled(self, classified_ad_contact_by_address_enabled):
        """Sets the classified_ad_contact_by_address_enabled of this ClassifiedAdPolicy.

        Indicates whether this category supports including an address in the seller's contact information. This element is for <b>For Sale By Owner</b> listings.   # noqa: E501

        :param classified_ad_contact_by_address_enabled: The classified_ad_contact_by_address_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_contact_by_address_enabled = classified_ad_contact_by_address_enabled

    @property
    def classified_ad_contact_by_email_enabled(self):
        """Gets the classified_ad_contact_by_email_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether most categories support including an email address in the seller's contact information.  # noqa: E501

        :return: The classified_ad_contact_by_email_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_contact_by_email_enabled

    @classified_ad_contact_by_email_enabled.setter
    def classified_ad_contact_by_email_enabled(self, classified_ad_contact_by_email_enabled):
        """Sets the classified_ad_contact_by_email_enabled of this ClassifiedAdPolicy.

        Indicates whether most categories support including an email address in the seller's contact information.  # noqa: E501

        :param classified_ad_contact_by_email_enabled: The classified_ad_contact_by_email_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_contact_by_email_enabled = classified_ad_contact_by_email_enabled

    @property
    def classified_ad_contact_by_phone_enabled(self):
        """Gets the classified_ad_contact_by_phone_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether most categories support including a phone number in the seller's contact information.  # noqa: E501

        :return: The classified_ad_contact_by_phone_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_contact_by_phone_enabled

    @classified_ad_contact_by_phone_enabled.setter
    def classified_ad_contact_by_phone_enabled(self, classified_ad_contact_by_phone_enabled):
        """Sets the classified_ad_contact_by_phone_enabled of this ClassifiedAdPolicy.

        Indicates whether most categories support including a phone number in the seller's contact information.  # noqa: E501

        :param classified_ad_contact_by_phone_enabled: The classified_ad_contact_by_phone_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_contact_by_phone_enabled = classified_ad_contact_by_phone_enabled

    @property
    def classified_ad_counter_offer_enabled(self):
        """Gets the classified_ad_counter_offer_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether counter offers are allowed on Best offers for the category.  # noqa: E501

        :return: The classified_ad_counter_offer_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_counter_offer_enabled

    @classified_ad_counter_offer_enabled.setter
    def classified_ad_counter_offer_enabled(self, classified_ad_counter_offer_enabled):
        """Sets the classified_ad_counter_offer_enabled of this ClassifiedAdPolicy.

        Indicates whether counter offers are allowed on Best offers for the category.  # noqa: E501

        :param classified_ad_counter_offer_enabled: The classified_ad_counter_offer_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_counter_offer_enabled = classified_ad_counter_offer_enabled

    @property
    def classified_ad_payment_method_enabled(self):
        """Gets the classified_ad_payment_method_enabled of this ClassifiedAdPolicy.  # noqa: E501

        This enumerated value indicates support for the payment method being displayed to the user for the category. Even if enabled, checkout may or may not be enabled. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdPaymentMethodEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :return: The classified_ad_payment_method_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: str
        """
        return self._classified_ad_payment_method_enabled

    @classified_ad_payment_method_enabled.setter
    def classified_ad_payment_method_enabled(self, classified_ad_payment_method_enabled):
        """Sets the classified_ad_payment_method_enabled of this ClassifiedAdPolicy.

        This enumerated value indicates support for the payment method being displayed to the user for the category. Even if enabled, checkout may or may not be enabled. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/sell/metadata/types/sel:ClassifiedAdPaymentMethodEnabledEnum'>eBay API documentation</a>  # noqa: E501

        :param classified_ad_payment_method_enabled: The classified_ad_payment_method_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: str
        """

        self._classified_ad_payment_method_enabled = classified_ad_payment_method_enabled

    @property
    def classified_ad_phone_count(self):
        """Gets the classified_ad_phone_count of this ClassifiedAdPolicy.  # noqa: E501

        Indicates how many contact phone numbers can be specified in contact information for the category. This element is for <b>For Sale By Owner</b> listings.  # noqa: E501

        :return: The classified_ad_phone_count of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: int
        """
        return self._classified_ad_phone_count

    @classified_ad_phone_count.setter
    def classified_ad_phone_count(self, classified_ad_phone_count):
        """Sets the classified_ad_phone_count of this ClassifiedAdPolicy.

        Indicates how many contact phone numbers can be specified in contact information for the category. This element is for <b>For Sale By Owner</b> listings.  # noqa: E501

        :param classified_ad_phone_count: The classified_ad_phone_count of this ClassifiedAdPolicy.  # noqa: E501
        :type: int
        """

        self._classified_ad_phone_count = classified_ad_phone_count

    @property
    def classified_ad_shipping_method_enabled(self):
        """Gets the classified_ad_shipping_method_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates if shipping methods can be specified and displayed in the <b>View Item</b> page for the category.  # noqa: E501

        :return: The classified_ad_shipping_method_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._classified_ad_shipping_method_enabled

    @classified_ad_shipping_method_enabled.setter
    def classified_ad_shipping_method_enabled(self, classified_ad_shipping_method_enabled):
        """Sets the classified_ad_shipping_method_enabled of this ClassifiedAdPolicy.

        Indicates if shipping methods can be specified and displayed in the <b>View Item</b> page for the category.  # noqa: E501

        :param classified_ad_shipping_method_enabled: The classified_ad_shipping_method_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._classified_ad_shipping_method_enabled = classified_ad_shipping_method_enabled

    @property
    def classified_ad_street_count(self):
        """Gets the classified_ad_street_count of this ClassifiedAdPolicy.  # noqa: E501

        Indicates how many street addresses can be specified in contact information for the category. This element is for <b>For Sale By Owner</b> listings.  # noqa: E501

        :return: The classified_ad_street_count of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: int
        """
        return self._classified_ad_street_count

    @classified_ad_street_count.setter
    def classified_ad_street_count(self, classified_ad_street_count):
        """Sets the classified_ad_street_count of this ClassifiedAdPolicy.

        Indicates how many street addresses can be specified in contact information for the category. This element is for <b>For Sale By Owner</b> listings.  # noqa: E501

        :param classified_ad_street_count: The classified_ad_street_count of this ClassifiedAdPolicy.  # noqa: E501
        :type: int
        """

        self._classified_ad_street_count = classified_ad_street_count

    @property
    def seller_contact_details_enabled(self):
        """Gets the seller_contact_details_enabled of this ClassifiedAdPolicy.  # noqa: E501

        Indicates whether this category supports seller-level contact information for Classified Ad listings.  # noqa: E501

        :return: The seller_contact_details_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :rtype: bool
        """
        return self._seller_contact_details_enabled

    @seller_contact_details_enabled.setter
    def seller_contact_details_enabled(self, seller_contact_details_enabled):
        """Sets the seller_contact_details_enabled of this ClassifiedAdPolicy.

        Indicates whether this category supports seller-level contact information for Classified Ad listings.  # noqa: E501

        :param seller_contact_details_enabled: The seller_contact_details_enabled of this ClassifiedAdPolicy.  # noqa: E501
        :type: bool
        """

        self._seller_contact_details_enabled = seller_contact_details_enabled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ClassifiedAdPolicy, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClassifiedAdPolicy):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
