# coding: utf-8

"""
    Translation API

    This API allows 3rd party developers to translate item titles.  # noqa: E501

    OpenAPI spec version: v1_beta.1.6
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Translation(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'original_text': 'str',
        'translated_text': 'str'
    }

    attribute_map = {
        'original_text': 'originalText',
        'translated_text': 'translatedText'
    }

    def __init__(self, original_text=None, translated_text=None):  # noqa: E501
        """Translation - a model defined in Swagger"""  # noqa: E501
        self._original_text = None
        self._translated_text = None
        self.discriminator = None
        if original_text is not None:
            self.original_text = original_text
        if translated_text is not None:
            self.translated_text = translated_text

    @property
    def original_text(self):
        """Gets the original_text of this Translation.  # noqa: E501

        The original text, in the language specified in the <b>from</b> field, that was input into the <b>text</b> field in the request.  # noqa: E501

        :return: The original_text of this Translation.  # noqa: E501
        :rtype: str
        """
        return self._original_text

    @original_text.setter
    def original_text(self, original_text):
        """Sets the original_text of this Translation.

        The original text, in the language specified in the <b>from</b> field, that was input into the <b>text</b> field in the request.  # noqa: E501

        :param original_text: The original_text of this Translation.  # noqa: E501
        :type: str
        """

        self._original_text = original_text

    @property
    def translated_text(self):
        """Gets the translated_text of this Translation.  # noqa: E501

        The translation of the original text into the language specified in the <b>to</b> field.  # noqa: E501

        :return: The translated_text of this Translation.  # noqa: E501
        :rtype: str
        """
        return self._translated_text

    @translated_text.setter
    def translated_text(self, translated_text):
        """Sets the translated_text of this Translation.

        The translation of the original text into the language specified in the <b>to</b> field.  # noqa: E501

        :param translated_text: The translated_text of this Translation.  # noqa: E501
        :type: str
        """

        self._translated_text = translated_text

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Translation, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Translation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
