# coding: utf-8

"""
    EDIS public shipping API

    <div class=\"msgbox_important\"><p class=\"msgbox_importantInDiv\" data-mc-autonum=\"&lt;b&gt;&lt;span style=&quot;color: #dd1e31;&quot; class=&quot;mcFormatColor&quot;&gt;Important! &lt;/span&gt;&lt;/b&gt;\"><span class=\"autonumber\"><span><b><span style=\"color: #dd1e31;\" class=\"mcFormatColor\">Important!</span></b></span></span> This method is only available for Greater-China based sellers with an active eDIS account.</p></div><br>This API allows 3rd party developers in the Greater-China area to process package shipping details.  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class GetTrackingDetailResponsesData(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'city': 'str',
        'country': 'str',
        'description_en': 'str',
        'description_zh': 'str',
        'district': 'str',
        'event_postal_code': 'str',
        'event_time': 'str',
        'province': 'str',
        'status': 'str',
        'tracking_number': 'str'
    }

    attribute_map = {
        'city': 'city',
        'country': 'country',
        'description_en': 'descriptionEn',
        'description_zh': 'descriptionZh',
        'district': 'district',
        'event_postal_code': 'eventPostalCode',
        'event_time': 'eventTime',
        'province': 'province',
        'status': 'status',
        'tracking_number': 'trackingNumber'
    }

    def __init__(self, city=None, country=None, description_en=None, description_zh=None, district=None, event_postal_code=None, event_time=None, province=None, status=None, tracking_number=None):  # noqa: E501
        """GetTrackingDetailResponsesData - a model defined in Swagger"""  # noqa: E501
        self._city = None
        self._country = None
        self._description_en = None
        self._description_zh = None
        self._district = None
        self._event_postal_code = None
        self._event_time = None
        self._province = None
        self._status = None
        self._tracking_number = None
        self.discriminator = None
        if city is not None:
            self.city = city
        if country is not None:
            self.country = country
        if description_en is not None:
            self.description_en = description_en
        if description_zh is not None:
            self.description_zh = description_zh
        if district is not None:
            self.district = district
        if event_postal_code is not None:
            self.event_postal_code = event_postal_code
        if event_time is not None:
            self.event_time = event_time
        if province is not None:
            self.province = province
        if status is not None:
            self.status = status
        if tracking_number is not None:
            self.tracking_number = tracking_number

    @property
    def city(self):
        """Gets the city of this GetTrackingDetailResponsesData.  # noqa: E501

        The city code in which the tracking event occurred.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid city codes.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The city of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """Sets the city of this GetTrackingDetailResponsesData.

        The city code in which the tracking event occurred.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid city codes.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param city: The city of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._city = city

    @property
    def country(self):
        """Gets the country of this GetTrackingDetailResponsesData.  # noqa: E501

        The two-letter ISO 3166 country code where the tracking event occurred.  # noqa: E501

        :return: The country of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """Sets the country of this GetTrackingDetailResponsesData.

        The two-letter ISO 3166 country code where the tracking event occurred.  # noqa: E501

        :param country: The country of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._country = country

    @property
    def description_en(self):
        """Gets the description_en of this GetTrackingDetailResponsesData.  # noqa: E501

        The English description of the tracking event.  # noqa: E501

        :return: The description_en of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._description_en

    @description_en.setter
    def description_en(self, description_en):
        """Sets the description_en of this GetTrackingDetailResponsesData.

        The English description of the tracking event.  # noqa: E501

        :param description_en: The description_en of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._description_en = description_en

    @property
    def description_zh(self):
        """Gets the description_zh of this GetTrackingDetailResponsesData.  # noqa: E501

        The Chinese description of the tracking event.  # noqa: E501

        :return: The description_zh of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._description_zh

    @description_zh.setter
    def description_zh(self, description_zh):
        """Sets the description_zh of this GetTrackingDetailResponsesData.

        The Chinese description of the tracking event.  # noqa: E501

        :param description_zh: The description_zh of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._description_zh = description_zh

    @property
    def district(self):
        """Gets the district of this GetTrackingDetailResponsesData.  # noqa: E501

        The district code where the tracking event occurred.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid district codes.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The district of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._district

    @district.setter
    def district(self, district):
        """Sets the district of this GetTrackingDetailResponsesData.

        The district code where the tracking event occurred.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for valid district codes.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param district: The district of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._district = district

    @property
    def event_postal_code(self):
        """Gets the event_postal_code of this GetTrackingDetailResponsesData.  # noqa: E501

        The postal code of where the tracking event occurred.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The event_postal_code of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._event_postal_code

    @event_postal_code.setter
    def event_postal_code(self, event_postal_code):
        """Sets the event_postal_code of this GetTrackingDetailResponsesData.

        The postal code of where the tracking event occurred.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param event_postal_code: The event_postal_code of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._event_postal_code = event_postal_code

    @property
    def event_time(self):
        """Gets the event_time of this GetTrackingDetailResponsesData.  # noqa: E501

        This timestamp the time and date the tracking event occurred.  # noqa: E501

        :return: The event_time of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._event_time

    @event_time.setter
    def event_time(self, event_time):
        """Sets the event_time of this GetTrackingDetailResponsesData.

        This timestamp the time and date the tracking event occurred.  # noqa: E501

        :param event_time: The event_time of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._event_time = event_time

    @property
    def province(self):
        """Gets the province of this GetTrackingDetailResponsesData.  # noqa: E501

        The province code where the tracking event occurred.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for province district codes.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :return: The province of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._province

    @province.setter
    def province(self, province):
        """Sets the province of this GetTrackingDetailResponsesData.

        The province code where the tracking event occurred.<br><br>See <a href=\"https://www.edisebay.com/open/development-guide-detail?id=36\" target=\"_blank\">商户API地址编码主数据</a> for province district codes.<br><br><span class=\"tablenote\"><b>Note:</b> This field is always returned, but will show as null or have an empty value if not defined/applicable.</span>  # noqa: E501

        :param province: The province of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._province = province

    @property
    def status(self):
        """Gets the status of this GetTrackingDetailResponsesData.  # noqa: E501

        The status of the shipment.  # noqa: E501

        :return: The status of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this GetTrackingDetailResponsesData.

        The status of the shipment.  # noqa: E501

        :param status: The status of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def tracking_number(self):
        """Gets the tracking_number of this GetTrackingDetailResponsesData.  # noqa: E501

        The tracking number specified in the request.  # noqa: E501

        :return: The tracking_number of this GetTrackingDetailResponsesData.  # noqa: E501
        :rtype: str
        """
        return self._tracking_number

    @tracking_number.setter
    def tracking_number(self, tracking_number):
        """Sets the tracking_number of this GetTrackingDetailResponsesData.

        The tracking number specified in the request.  # noqa: E501

        :param tracking_number: The tracking_number of this GetTrackingDetailResponsesData.  # noqa: E501
        :type: str
        """

        self._tracking_number = tracking_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(GetTrackingDetailResponsesData, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetTrackingDetailResponsesData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
