# coding: utf-8

"""
    Media API

    The <b>Media API</b> lets sellers to create, upload, and retrieve files, including:<ul><li>images</li><li>videos</li><li>documents (for GPSR regulations)</li></ul>  # noqa: E501

    OpenAPI spec version: v1_beta.4.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class CreateDocumentFromUrlRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'document_type': 'str',
        'document_url': 'str',
        'languages': 'list[str]'
    }

    attribute_map = {
        'document_type': 'documentType',
        'document_url': 'documentUrl',
        'languages': 'languages'
    }

    def __init__(self, document_type=None, document_url=None, languages=None):  # noqa: E501
        """CreateDocumentFromUrlRequest - a model defined in Swagger"""  # noqa: E501
        self._document_type = None
        self._document_url = None
        self._languages = None
        self.discriminator = None
        if document_type is not None:
            self.document_type = document_type
        if document_url is not None:
            self.document_url = document_url
        if languages is not None:
            self.languages = languages

    @property
    def document_type(self):
        """Gets the document_type of this CreateDocumentFromUrlRequest.  # noqa: E501

        The type of the document being created. For example, a <code>USER_GUIDE_OR_MANUAL</code> or a <code>SAFETY_DATA_SHEET</code>. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/commerce/media/types/api:DocumentTypeEnum'>eBay API documentation</a>  # noqa: E501

        :return: The document_type of this CreateDocumentFromUrlRequest.  # noqa: E501
        :rtype: str
        """
        return self._document_type

    @document_type.setter
    def document_type(self, document_type):
        """Sets the document_type of this CreateDocumentFromUrlRequest.

        The type of the document being created. For example, a <code>USER_GUIDE_OR_MANUAL</code> or a <code>SAFETY_DATA_SHEET</code>. For implementation help, refer to <a href='https://developer.ebay.com/api-docs/commerce/media/types/api:DocumentTypeEnum'>eBay API documentation</a>  # noqa: E501

        :param document_type: The document_type of this CreateDocumentFromUrlRequest.  # noqa: E501
        :type: str
        """

        self._document_type = document_type

    @property
    def document_url(self):
        """Gets the document_url of this CreateDocumentFromUrlRequest.  # noqa: E501

        The URL of the document being created.<br><br>The document referenced by the URL must be a .pdf, .png, .jpg, or .jpeg file, and must be no larger than 10 MB.  # noqa: E501

        :return: The document_url of this CreateDocumentFromUrlRequest.  # noqa: E501
        :rtype: str
        """
        return self._document_url

    @document_url.setter
    def document_url(self, document_url):
        """Sets the document_url of this CreateDocumentFromUrlRequest.

        The URL of the document being created.<br><br>The document referenced by the URL must be a .pdf, .png, .jpg, or .jpeg file, and must be no larger than 10 MB.  # noqa: E501

        :param document_url: The document_url of this CreateDocumentFromUrlRequest.  # noqa: E501
        :type: str
        """

        self._document_url = document_url

    @property
    def languages(self):
        """Gets the languages of this CreateDocumentFromUrlRequest.  # noqa: E501

        This array shows the language(s) used in the document.  # noqa: E501

        :return: The languages of this CreateDocumentFromUrlRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._languages

    @languages.setter
    def languages(self, languages):
        """Sets the languages of this CreateDocumentFromUrlRequest.

        This array shows the language(s) used in the document.  # noqa: E501

        :param languages: The languages of this CreateDocumentFromUrlRequest.  # noqa: E501
        :type: list[str]
        """

        self._languages = languages

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(CreateDocumentFromUrlRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateDocumentFromUrlRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
